const fs = require('fs');
const path = require('path');

// Function to read JSON results and generate HTML report
function generateHtmlReport() {
  const resultsFilePath = path.join(__dirname, 'k6-tests', 'results.json');
  const reportFilePath = path.join(__dirname, 'k6-tests', 'report.html');

  if (!fs.existsSync(resultsFilePath)) {
    console.error('Error: Results file not found. Please run the K6 tests first.');
    return;
  }

  const results = JSON.parse(fs.readFileSync(resultsFilePath, 'utf-8'));

  // Basic HTML report structure
  let htmlContent = `
    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>K6 Test Report</title>
        <style>
            body { font-family: Arial, sans-serif; }
            table { width: 100%; border-collapse: collapse; }
            th, td { border: 1px solid #ddd; padding: 8px; }
            th { background-color: #f2f2f2; }
        </style>
    </head>
    <body>
        <h1>K6 Test Report</h1>
        <h2>Summary</h2>
        <table>
            <tr>
                <th>Metric</th>
                <th>Value</th>
            </tr>
            <tr>
                <td>Total Requests</td>
                <td>${results.metrics.http_reqs.value}</td>
            </tr>
            <tr>
                <td>Failed Requests</td>
                <td>${results.metrics.http_req_failed.value}</td>
            </tr>
            <tr>
                <td>Average Response Time</td>
                <td>${results.metrics.http_req_duration.value} ms</td>
            </tr>
        </table>
    </body>
    </html>
  `;

  // Write the HTML report to a file
  fs.writeFileSync(reportFilePath, htmlContent);
  console.log('Generated HTML report: report.html');
}

// Execute the report generation
generateHtmlReport();
